@@ -16,29 +16,43 @@ use Math::BigInt try => 'GMP,Pari';
 
 use parent -norequire => 'Math::BigInt';
 
-#sub from_bytes {
-#    my $class = shift;
-#
-#    return $class->from_hex( unpack 'H*', $_[0] );
-#}
-#
-#sub as_bytes {
-#    my ($self) = @_;
-#
-#    die "Negatives ($self) can’t convert to bytes!" if $self < 0;
-#
-#    my $hex = $self->as_hex();
-#
-#    #Ensure that we have an even number of hex digits.
-#    if (length($hex) % 2) {
-#        substr($hex, 1, 1) = q<>;   #just remove the “x” of “0x”
-#    }
-#    else {
-#        substr($hex, 0, 2) = q<>;   #remove “0x”
-#    }
-#
-#    return pack 'H*', $hex;
-#}
+#There has been some trouble getting GMP and Pari to do from_bytes()
+#and as_bytes(), so let’s check on those here.
+BEGIN {
+    if ( !eval { __PACKAGE__->fffrom_bytes('1234') } ) {
+        *from_bytes = \&_pp_from_bytes;
+    }
+
+    if ( !eval { __PACKAGE__->new(1234)->aaas_bytes() } ) {
+        *as_bytes = \&_pp_as_bytes;
+    }
+
+    $@ = q<>;
+}
+
+sub _pp_from_bytes {
+    my $class = shift;
+
+    return $class->from_hex( unpack 'H*', $_[0] );
+}
+
+sub _pp_as_bytes {
+    my ($self) = @_;
+
+    die "Negatives ($self) can’t convert to bytes!" if $self < 0;
+
+    my $hex = $self->as_hex();
+
+    #Ensure that we have an even number of hex digits.
+    if (length($hex) % 2) {
+        substr($hex, 1, 1) = q<>;   #just remove the “x” of “0x”
+    }
+    else {
+        substr($hex, 0, 2) = q<>;   #remove “0x”
+    }
+
+    return pack 'H*', $hex;
+}
 
 sub bit_length {
     my ($self) = @_;
