@@ -50,14 +50,10 @@ not be difficult to integrate—but do any CAs accept them?
 
 =head1 ECDSA KEY FORMAT
 
-As of version 0.13, this module produces CSRs with explicit ECDSA curve
-parameters rather than
-merely indicating the curve parameters by the name of the curve. This makes
-the resulting CSR bigger, but it also prevents compatibility issues with ECDSA
-implementations (e.g., old OpenSSL versions) that don’t know about newer
-curves.
-
-If you need to produce CSRs with a named curve, let me know.
+After a brief flirtation (cf. v0.13) with producing ECDSA-signed CSRs using
+explicit curve parameters, this module produces CSRs using B<named> curves.
+Certificate authorities seem to prefer this format—which makes sense since
+they only allow certain curves in the first place.
 
 =head1 SIGNATURE DIGEST ALGORITHMS
 
@@ -203,7 +199,7 @@ sub _encode_params {
             return $key->sign( Digest::SHA->can("sha$bits")->($msg) );
         };
 
-        $pk_der = $key->get_public_key()->to_der_with_explicit_curve();
+        $pk_der = $key->get_public_key()->to_der_with_curve_name();
     }
     elsif ($key->isa('Crypt::Perl::RSA::PrivateKey')) {
         $sig_alg = 'sha512WithRSAEncryption';
